--
--  My_Photo_ManipulatorAppDelegate.applescript
--  My Photo Manipulator
--
--  Created by Ben Waldie on 1/18/11.
--  Copyright 2011 Automated Workflows, LLC. All rights reserved.

script My_Photo_ManipulatorAppDelegate
	property parent : class "NSObject"
	
	property photoPath : ""
	property outputFolderPath : ""
	
	property flipHorizontal : false
	property flipVertical : false
	property applyRotation : false
	property applyScaling : false
	
	property rotationAmount : 90
	property scaleAmount : 150
	
	property scaleUnits : "pixels"
	property outputType : "JPEG"
	
	property imageView : missing value
	
	on applicationWillFinishLaunching_(aNotification)
		-- Insert code here to initialize your application before any files are opened 
	end applicationWillFinishLaunching_
	
	on applicationShouldTerminate_(sender)
		-- Insert code here to do any housekeeping before your application quits 
		return current application's NSTerminateNow
	end applicationShouldTerminate_
	
	on browseForPhoto_(sender)
		set thePath to (choose file with prompt "Please select an image:" without invisibles)
		set theImage to initWithContentsOfFile_(POSIX path of thePath) of alloc() of class "NSImage" of current application
		setPhotoPath_(thePath as string)
		setImage_(theImage) of imageView
	end browseForPhoto_
	
	on browseForOutputFolder_(sender)
		set thePath to (choose folder with prompt "Please select an output folder:" without invisibles)
		setOutputFolderPath_(thePath as string)
	end browseForOutputFolder_
	
	on processPhoto_(sender)
		set thePhoto to photoPath as string
		set theOutputFolder to outputFolderPath as string
		set flipH to flipHorizontal as boolean
		set flipV to flipVertical as boolean
		set rotateImage to applyRotation as boolean
		set scaleImage to applyScaling as boolean
		set theRotationAmount to rotationAmount as integer
		set theScalingAmount to scaleAmount as integer
		set theUnits to scaleUnits as string
		set theOutputType to outputType as string
		
		if thePhoto = "" then return
		if theOutputFolder = "" then return
		if rotateImage = true then
			if rotationAmount = 0 then set rotateImage to false
		end if
		if applyScaling = true then
			if scaleAmount = 0 then set scaleImage to false
		end if
		
		tell application "Image Events"
			launch
			set theImage to open thePhoto
			tell theImage
				set theImageName to name
				flip horizontal flipH vertical flipV
				if rotateImage = true then rotate to angle theRotationAmount
				if scaleImage = true then
					if theUnits = "pixels" then
						scale to size theScalingAmount
					else
						scale by factor theScalingAmount / 100
					end if
				end if
				set theSavePath to theOutputFolder & theImageName as string
				if theOutputType = "BMP" then
					save as BMP in (theSavePath & ".bmp")
				else if theOutputType = "JPEG" then
					save as JPEG in (theSavePath & ".jpg")
				else if theOutputType = "TIFF" then
					save as TIFF in (theSavePath & ".tif")
				end if
				close
			end tell
		end tell
		
		activate
		display alert "Processing complete!" message "Your image has been manipulated." buttons {"OK"} default button "OK"
	end processPhoto_
	
end script